﻿B4J=true
Group=Modules
ModulesStructureVersion=1
Type=StaticCode
Version=10
@EndOfDesignText@
'Static code module
Sub Process_Globals
	Private fx As JFX
	Private item_modal As Form
	Private tblItems As TableView
	Private tfSearchString As TextField

	Private chbItemType As ChoiceBox
	Private taDescription As TextArea
	Private tfItemName As TextField
	Private tfQuantity As TextField
	Private tfUnitPrice As TextField
	Private chbUOM As ChoiceBox
	
	Private openMode As String
	
End Sub


Public Sub LoadLayout
	MDI.Workarea.InnerNode.RemoveNodeFromParent
	MDI.Workarea.LoadLayout("items_list", MDI.Workarea.InnerNode.PrefWidth, MDI.Workarea.InnerNode.PrefHeight)
	Wait For (getItems) Complete (Success As Boolean)
	
End Sub

Private Sub getItems As ResumableSub
	If Libraries.SQL.IsInitialized = False Then
		Libraries.SQL.InitializeSQLite(File.DirApp, "zalon.db", True)
	End If
	
	Try
		Dim qry As String = "SELECT id, [name] as Name, [description] As Description, [type] As Type, [unitprice] As 'Unit Price', [quantity] As Quantity FROM items WHERE published = ?  ORDER BY id DESC LIMIT 15"
		Dim SenderFilter As Object = Libraries.SQL.ExecQueryAsync("SQL", qry, Array As String(1))
		Wait For (SenderFilter) SQL_QueryComplete (Success As Boolean, rs As ResultSet)
		If Success Then
			tblItems.Items.Clear
			Dim cols As List
			cols.Initialize
			cols.Add("Id")
			cols.Add("Name")
			cols.Add("Description")
			cols.Add("Type")
			cols.Add("Unit Price")
			cols.Add("Quantity")
			tblItems.SetColumns(cols)
			Do While rs.NextRow
				Dim values(rs.ColumnCount) As String
				For col = 0 To rs.ColumnCount - 1
					values(col) = rs.GetString2(col)
				Next
				tblItems.Items.Add(values)
			Loop
		Else
			Log(LastException)
		End If
		
	Catch
		Log(LastException.Message)
	End Try
	
	Libraries.SQL.Close
	Return True
End Sub

Private Sub btnAdd_MouseClicked (EventData As MouseEvent)
	openMode = "ADD"
	
	If item_modal.IsInitialized = False Then
		item_modal.Initialize("item_modal", 500, 400)
		item_modal.RootPane.LoadLayout("item_modal")
		Metro.ApplyTheme(item_modal,"Light")
		item_modal.SetFormStyle("UNDECORATED")
		item_modal.Resizable = False
	End If
	
	chbItemType.Items.AddAll(Array As String("SERVICE", "PRODUCT", "Others"))
	chbItemType.SelectedIndex = 0
	chbUOM.Items.AddAll(Array As String("NA","pc", "kilo", "lb", "box"))
	chbUOM.SelectedIndex = 0
	item_modal.ShowAndWait
	item_modal.Close
	
End Sub

Private Sub btnClose_MouseClicked (EventData As MouseEvent)
	item_modal.Close
End Sub

Private Sub item_modal_Closed
	item_modal.Close
End Sub

Private Sub btnUpdate_MouseClicked (EventData As MouseEvent)
	
	Dim itemName As String = tfItemName.Text
	Dim itemDescription As String = taDescription.Text
	Dim quantity As String = tfQuantity.Text
	Dim uom As Int = chbItemType.SelectedIndex
	Dim unitprice As String = tfUnitPrice.Text
	Dim itemType As Int = chbItemType.SelectedIndex
	Dim createdAtTicks As String = DateTime.DateTimeParse(DateTime.Date(DateTime.Now), DateTime.Time(DateTime.Now))
	Dim createdBy As Int = Variables.userId
	Dim updatedAtTicks As String = DateTime.DateTimeParse(DateTime.Date(DateTime.Now), DateTime.Time(DateTime.Now))
	Dim updatedBy As Int = Variables.userId
	
	If Libraries.SQL.IsInitialized = False Then
		Libraries.SQL.InitializeSQLite(File.DirApp, "zalon.db", True)
	End If
	
	Libraries.SQL.BeginTransaction
	
	If openMode = "ADD" Then
		Try
			Libraries.SQL.ExecNonQuery2($"INSERT INTO items
				(name, description, type, uom, unitprice, quantity, createdAt, createdBy, updatedAt, updatedBy, published)
				VALUES (?,?,?,?,?,?,?,?,?,?,?)"$, Array As Object(itemName, itemDescription, itemType, uom, unitprice, quantity, _
				createdAtTicks, createdBy, updatedAtTicks, updatedBy, 1))
	
			Libraries.SQL.TransactionSuccessful
			Libraries.XUI.MsgboxAsync("New item added.", "Success")
		Catch
			Libraries.XUI.MsgboxAsync("Error saving.", "Error")
			Log(LastException.Message)
			Libraries.SQL.RollBack 'no changes will be made
		End Try
	else if openMode = "EDIT" Then
		Try
			Libraries.SQL.ExecNonQuery2($"UPDATE items SET name = ?, description = ?, type = ?, unitprice = ?, quantity = ?, updatedAt = ?, updatedBy = ?, published = ? WHERE id = ${Variables.itemId}"$, _
			Array As Object(itemName, itemDescription, itemType, unitprice, quantity, updatedAtTicks, updatedBy, 1))
	
			Libraries.SQL.TransactionSuccessful
			Libraries.XUI.MsgboxAsync("Item Updated.", "Success")
		Catch
			Libraries.XUI.MsgboxAsync("Error updating.", "Error")
			Log(LastException.Message)
			Libraries.SQL.RollBack 'no changes will be made
		End Try
	End If
	
	openMode = "EDIT"
	
	Libraries.SQL.Close
	
	getItems
	item_modal_Closed
	
End Sub

Private Sub btnOpen_MouseClicked (EventData As MouseEvent)
	Dim row() As Object = tblItems.SelectedRowValues

	openMode = "EDIT"
	
	If item_modal.IsInitialized = False Then
		item_modal.Initialize("item_modal", 500, 400)
		item_modal.RootPane.LoadLayout("item_modal")
		Metro.ApplyTheme(item_modal,"Light")
		item_modal.Resizable = False
		item_modal.SetFormStyle("UNDECORATED")
		chbItemType.Items.AddAll(Array As String("SERVICE", "PRODUCT", "Others"))
		chbUOM.Items.AddAll(Array As String("NA","pc", "kilo", "lb", "box"))
	End If
	
	If Libraries.SQL.IsInitialized = False Then
		Libraries.SQL.InitializeSQLite(File.DirApp, "zalon.db", True)
	End If
	
	Try
		Dim qry As String = "SELECT * FROM items WHERE published = ?  AND id = ?"
		Dim SenderFilter As Object = Libraries.SQL.ExecQueryAsync("SQL", qry, Array As Object(1, row(0)))
		Wait For (SenderFilter) SQL_QueryComplete (Success As Boolean, rs As ResultSet)
		
		Do While rs.NextRow
			Variables.itemId = rs.GetInt("id")
			Variables.itemName = rs.GetString("name")
			Variables.itemDescription = rs.GetString("description")
			Variables.itemType = rs.GetInt("type")
			Variables.itemUnitPrice = rs.GetString("unitprice")
			Variables.itemQuantity = rs.GetString("quantity")
			Variables.itemUOM= rs.GetInt("uom")
			Variables.clientCreatedAt = rs.GetString("createdAt")
			Variables.clientCreatedBy = rs.GetInt("createdBy")
			Variables.clientUpdatedAt = rs.GetString("updatedAt")
			Variables.clientUpdatedBy = rs.GetInt("updatedBy")
			Variables.clientPublished = rs.GetInt("updatedBy")
		Loop
	Catch
		Log(LastException.Message)
	End Try
	
	tfItemName.Text = Variables.itemName
	taDescription.Text = Variables.itemDescription
	chbItemType.SelectedIndex = Variables.itemType
	tfUnitPrice.Text = Variables.itemUnitPrice
	tfQuantity.Text = Variables.itemQuantity
	chbUOM.SelectedIndex = Variables.itemUOM
	
	item_modal.ShowAndWait
End Sub